<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Spatie\Permission\Models\Role;

class CreateAdminUser extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'app:create-admin-user';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Create default admin user';

    /**
     * Execute the console command.
     */
    public function handle()
    {
        // Prompt for admin user details
        $name = $this->ask('What is the name of the admin user?');
        $email = $this->ask('What is the email of the admin user?');
        $password = $this->secret('What is the password?');

        // Check if the user with this email already exists
        $user = User::where('email', $email)->first();

        if ($user) {
            $this->info('User with this email already exists: ' . $email);
        } else {
            // Create the admin user
            $admin = User::create([
                'name' => $name,
                'email' => $email,
                'password' => Hash::make($password),
            ]);

            // Assign the "admin" role
            $adminRole = Role::firstOrCreate(['name' => 'admin']);
            $admin->assignRole($adminRole);

            $this->info('Admin user created successfully!');
        }

        return Command::SUCCESS;
    }
}
