<?php

namespace App\DataTables\backend;

use App\Models\Terminal;
use Illuminate\Database\Eloquent\Builder as QueryBuilder;
use Yajra\DataTables\EloquentDataTable;
use Yajra\DataTables\Html\Builder as HtmlBuilder;
use Yajra\DataTables\Html\Button;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Html\Editor\Editor;
use Yajra\DataTables\Html\Editor\Fields;
use Yajra\DataTables\Services\DataTable;

class TerminalsDataTable extends DataTable
{
    /**
     * Build the DataTable class.
     *
     * @param QueryBuilder $query Results from query() method.
     */
    public function dataTable(QueryBuilder $query): EloquentDataTable
    {
        return (new EloquentDataTable($query))
            ->addColumn('#', function () {
                static $rowNumber = 0; // Static variable to maintain state
                return ++$rowNumber;   // Increment and return the row number
            })
            ->addColumn('action', function ($terminal) {
                return '<a data-id="'.$terminal->id.'" class="btn btn-sm btn-primary edit-terminal-btn"><i class="bi bi-pencil-square"></i></a>
                        <a data-id="'.$terminal->id.'" class="btn btn-sm btn-danger delete-terminal-btn"><i class="bi bi-trash3-fill"></i></a>';
            })
            ->addColumn('status', function ($terminal) {
                // Custom rendering for status
                return $terminal->terminal_status == 1
                    ? '<span class="badge bg-success">Active</span>'
                    : '<span class="badge bg-danger">Inactive</span>';
            })
            ->rawColumns(['status', 'action'])
            ->setRowId('id');
    }

    /**
     * Get the query source of dataTable.
     */
    public function query(Terminal $model): QueryBuilder
    {
        return $model->newQuery()->with('airport');
    }

    /**
     * Optional method if you want to use the html builder.
     */
    public function html(): HtmlBuilder
    {
        return $this->builder()
            ->setTableId('terminals-table')
            ->columns($this->getColumns())
            ->minifiedAjax()
            //->dom('Bfrtip')
            ->orderBy(1)
            ->selectStyleSingle()
            ->addTableClass('table table-bordered table-hover dataTable dtr-inline')
            ->buttons([
                Button::make('excel'),
                Button::make('csv'),
                Button::make('pdf'),
                Button::make('print')
            ]);
    }

    /**
     * Get the dataTable columns definition.
     */
    public function getColumns(): array
    {
        return [
            Column::make('#'),
            Column::make('terminal_name'),
            Column::make('airport.name'),
            Column::make('status')->title('Status'),
            Column::computed('action')
                ->exportable(false)
                ->printable(false)
                ->width(60)
                ->addClass('text-center')
        ];
    }

    /**
     * Get the filename for export.
     */
    protected function filename(): string
    {
        return 'Terminals_' . date('YmdHis');
    }
}
