<?php

namespace App\Http\Controllers;

use App\Services\AirportService;
use Illuminate\View\View;
use Illuminate\Http\Request;

class HomeController extends Controller
{
    private AirportService $airportService;

    public function __construct(AirportService $airportService)
    {
        $this->airportService = $airportService;
    }

    /**
     * Display the home page.
     */
    public function index(): View
    {
        $airports = $this->airportService->listAirports();

        $countries = [
            'US' => 'United States',
            'CA' => 'Canada',
            'FR' => 'France',
            'DE' => 'Germany'
        ];

        $features = [
            [
                'icon' => 'feature-1.svg',
                'title' => 'Feature Title Goes Here',
                'descriptions' => [
                    'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.',
                    'Ut enim ad minim veniam, quis nostrud exercitation ullamco.',
                    'Duis aute irure dolor in reprehenderit in voluptate velit .'
                ]
            ],
            [
                'icon' => 'emoji_transportation.svg',
                'title' => 'Feature Title Goes Here',
                'descriptions' => [
                    'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.',
                    'Ut enim ad minim veniam, quis nostrud exercitation ullamco.',
                    'Duis aute irure dolor in reprehenderit in voluptate velit .'
                ]
            ],
            [
                'icon' => 'car_tag.svg',
                'title' => 'Feature Title Goes Here',
                'descriptions' => [
                    'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.',
                    'Ut enim ad minim veniam, quis nostrud exercitation ullamco.',
                    'Duis aute irure dolor in reprehenderit in voluptate velit .'
                ]
            ]
        ];

        $services = [
            'meet_greet' => [
                'title' => 'Meet & Greet',
                'image' => 'bg_img_meet_greet.svg',
                'descriptions' => [
                    'Meet & Greet is a premium service, also known as valet parking. This is where a professional driver from your chosen company meets you at the terminal to collect your vehicle and park it securely on your behalf.',
                    'On your return, your car will be ready at the terminal, for a quick and easy handover. This service is safely parked while you travel and is available when you return making your travel experience smooth.'
                ]
            ],
            'park_ride' => [
                'title' => 'Park & Ride',
                'image' => 'bg_img_park_ride.svg',
                'descriptions' => [
                    'Park & Ride is the most budget - friendly parking option providing excellent value without compromising on service. After parking your vehicle you can enjoy a complimentary shuttle bus that departs every 5 to 15 minutes taking you directly to the terminal.',
                    'This service combines affordability and customer care, allowing you to relax and enjoy the ride without worrying about the safety of your vehicle. As our park and ride service is designed with security in mind ensuring your car is protected while you travel.'
                ]
            ]
        ];

        $searchModalFeatures = [
            [
                'icon' => 'ic_feature1.svg',
                'description' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor.'
            ],
            [
                'icon' => 'ic_feature2.svg',
                'description' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor.'
            ],
            [
                'icon' => 'ic_feature3.svg',
                'description' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor.'
            ]
        ];

        return view('home', compact(
            'countries',
            'features',
            'services',
            'searchModalFeatures',
            'airports'
        ));
    }
}
