<?php

namespace App\Http\Controllers\backend;

use App\DataTables\backend\AirportsDataTable;
use App\Http\Controllers\Controller;
use App\Models\Airport;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;

class AirportController extends Controller
{
    public function __construct(private Airport $model) { }

    /**
     * Display a listing of the resource.
     */
    public function index(AirportsDataTable $dataTable)
    {
        $data = ['title' => 'Configure Airport Information'];
        return $dataTable->render('backend.airport',$data);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        try {
            $request->validate(Airport::$rules);

            $airport = $this->model->create([
                'name' => $request->name,
                'country' => $request->country,
                'address' => $request->address,
                'email' => $request->email,
                'latitude' => $request->latitude,
                'longitude' => $request->longitude,
                'status' => $request->status ?? true

            ]);

            return response()->json([
                'message' => 'Airport saved successfully!',
            ]);
        } catch (\Illuminate\Validation\ValidationException $e) {
            // Handle validation errors
            return response()->json([
                'message' => 'Validation failed.',
                'errors' => $e->errors(),
            ], 422); // HTTP 422 Unprocessable Entity

        } catch (\Exception $e) {
            // Log the error for debugging
            Log::error('Error saving airport: ' . $e->getMessage());

            // Return a generic error message
            return response()->json([
                'message' => 'An error occurred while saving the airport. Please try again.',
            ], 500); // HTTP 500 Internal Server Error
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        try {
            // Fetch the company data by ID
            $airport = $this->model->findOrFail($id);

            // Return the company data as JSON
            return response()->json($airport);

        } catch (\Exception $e) {
            // Log the error for debugging
            Log::error('Error fetching product details: ' . $e->getMessage());

            // Return a generic error message
            return response()->json([
                'message' => 'An error occurred while fetching product details. Please try again.',
            ], 500); // HTTP 500 Internal Server Error
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        try {
            $request->validate(Airport::$rules);

            $airport = $this->model->findOrFail($id); // Find the product by ID

            // Update product data
            $airport->name = $request->name;
            $airport->country = $request->country;
            $airport->address = $request->address;
            $airport->email = $request->email;
            $airport->latitude = $request->latitude;
            $airport->longitude = $request->longitude;
            $airport->status = $request->status ?? true;
            $airport->save();

            return response()->json([
                'message' => 'Airport updated successfully!',
            ], 200); // HTTP 200 OK

        } catch (\Illuminate\Validation\ValidationException $e) {
            return response()->json([
                'message' => 'Validation failed.',
                'errors' => $e->errors(),
            ], 422); // HTTP 422 Unprocessable Entity

        } catch (\Exception $e) {
            Log::error('Error updating airport: ' . $e->getMessage());
            return response()->json([
                'message' => 'An error occurred while updating the airport. Please try again.',
            ], 500); // HTTP 500 Internal Server Error
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        try {
            $airport = $this->model->findOrFail($id); // Find the product by ID
            $airport->delete(); // Soft delete the product

            return response()->json([
                'message' => 'Airport deleted successfully!',
            ], 200); // HTTP 200 OK

        } catch (\Exception $e) {
            Log::error('Error deleting airport: ' . $e->getMessage());
            return response()->json([
                'message' => 'An error occurred while deleting the airport. Please try again.',
            ], 500); // HTTP 500 Internal Server Error
        }
    }
}
