<?php

namespace App\Http\Controllers\backend;

use App\Models\Site;
use App\Http\Requests\StoreSiteRequest;
use App\Http\Requests\UpdateSiteRequest;
use App\Services\BookingService;
use Carbon\Carbon;
use DB;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class BookingAdminController extends Controller
{
    private BookingService $bookingService;
    public function __construct(BookingService $bookingService)
    {
        $this->bookingService = $bookingService;
    }

    public function bookNow($id = null){
        $title = 'Booking Information';

        $products = DB::table('products')->select('id','name')->get();
        $company = DB::table('companies')->select('id','name')->get();
        $terminals = DB::table('terminals')->where('terminal_status', 1)->select('id','terminal_name')->get();
        $airports = DB::table('airports')->select('id','name')->get();
        $user_title = ['Not mentioned'=> 'Not mentioned','Mr'=>'Mr','Mrs'=>'Mrs','Ms'=>'Ms'];

        $booking = null;
        if ($id) {
            $booking = DB::table('bookings')->where('id', $id)->first();
        }

        // Initialize variables
        $customer = null;
        $vehicle = null;

        return view('backend.booking.book_now', compact('title','products','company','terminals','airports','user_title', 'booking','customer','vehicle'));
    }

    public function storeBookNow(Request $request){//var_dump($request->all());
        $validatedData = $request->validate([
            'product' => 'required|string|max:255',
            'agent' => 'required|string|max:255',
            'ref_no' => 'required',
            'airport' => 'required',
            'terminal_in' => 'required',
            'terminal_out' => 'required',
            'departure_flight' => 'required',
            'return_flight' => 'required',
            'datetimepicker_departure' => 'required|date',
            'datetimepicker_return' => 'required|date',
            'price' => 'required',
            'title' => 'required',
            'name' => 'required',
            'email' => 'required|email',
            'mobile' => 'required',
            'make_model' => 'required',
            'reg_no' => 'required',
            'colour' => 'required',
            'passengers' => 'required',
            'note' => '',
        ]);

        // Example: User::create($validatedData);

        try {
            // Begin a transaction
            DB::beginTransaction();

            $cus_id = DB::table('customers')->insertGetId([
                'title' => $validatedData['title'],
                'first_name' => $validatedData['name'],
                'last_name' => $validatedData['name'],
                'mobile' => $validatedData['mobile'],
                'email' => $validatedData['email'],
                'created_at' => Carbon::now(),
                'updated_at' => Carbon::now(),
            ]);

            if(!empty($cus_id)) {
                $bookingData = [
                    'company_id' => $validatedData['agent'],
                    'airport_id' => $validatedData['airport'],
                    'product_id' => $validatedData['product'],
                    'price' => $validatedData['price'],
                    'net_price' => $validatedData['price'],
                    'total_amount' => $validatedData['price'],
                    'status' => 'pending',
                    'customer_id' => $cus_id,
                    'booking_date' => Carbon::now(),
                    'date_from' => $validatedData['datetimepicker_departure'],
                    'date_to' => $validatedData['datetimepicker_return'],
                    'created_at' => Carbon::now(),
                    'updated_at' => Carbon::now(),
                ];
                $booking_id = $this->bookingService->createBooking($bookingData);

                //$booking_id = DB::table('bookings')->insertGetId($bookingData);
            }

            if(!empty($cus_id) && !empty($booking_id)) {
                DB::table('vehicles')->insert([
                    'customer_id' => $cus_id,
                    'booking_id' => $booking_id,
                    'vehicle_no' => $validatedData['reg_no'],
                    'vehicle_make' => $validatedData['make_model'],
                    'vehicle_model' => $validatedData['make_model'],
                    'vehicle_color' => $validatedData['colour'],
                    'created_at' => Carbon::now(),
                    'updated_at' => Carbon::now(),
                ]);
            }

            // Commit the transaction if all queries are successful
            DB::commit();

            // Success response or redirect
            return redirect()->back()->with('success', 'Booking registered successfully!');
        } catch (\Exception $e) {
            // Rollback the transaction on failure
            DB::rollBack();

            // Return error response or redirect
            return redirect()->back()->with('error', 'An error occurred while saving data.');
        }
    }

    public function edit($id)
    {
        $title = 'Booking Information Update';

        // Fetch the booking by ID
        $booking = DB::table('bookings')->where('id', $id)->first();

        // If booking not found, redirect back with an error message
        if (!$booking) {
            return redirect()->route('backend.booking.book_now')->with('error', 'Booking not found.');
        }

        // Fetch related customer details
        $customer = DB::table('customers')->where('id', $booking->customer_id)->first();

        // Fetch related vehicle details
        $vehicle = DB::table('vehicles')->where('booking_id', $booking->id)->first();

        // Fetch necessary data for the form dropdowns
        $products = DB::table('products')->select('id', 'name')->get();
        $company = DB::table('companies')->select('id', 'name')->get();
        $terminals = DB::table('terminals')->where('terminal_status', '1')->select('id', 'terminal_name')->get();
        $airports = DB::table('airports')->select('id', 'name')->get();
        $user_title = ['Not mentioned' => 'Not mentioned', 'Mr' => 'Mr', 'Mrs' => 'Mrs', 'Ms' => 'Ms'];

        // Pass all data to the view
        return view('backend.booking.book_now', compact(
            'title',
            'booking',
            'customer',
            'vehicle',
            'products',
            'company',
            'terminals',
            'airports',
            'user_title',
        ));
    }
    public function updateBookNow(Request $request, $id)
    {
        // Validate the request data
        $validatedData = $request->validate([
            'product' => 'required|string|max:255',
            'agent' => 'required|string|max:255',
            'ref_no' => 'required',
            'airport' => 'required',
            'terminal_in' => 'required',
            'terminal_out' => 'required',
            'departure_flight' => 'required',
            'return_flight' => 'required',
            'datetimepicker_departure' => 'required|date',
            'datetimepicker_return' => 'required|date',
            'price' => 'required',
            'title' => 'required',
            'name' => 'required',
            'email' => 'required|email',
            'mobile' => 'required',
            'make_model' => 'required',
            'reg_no' => 'required',
            'colour' => 'required',
            'passengers' => 'required',
            'note' => '',
        ]);

        try {
            // Begin a transaction
            DB::beginTransaction();

            // Fetch the booking and customer details
            $booking = DB::table('bookings')->where('id', $id)->first();
            if (!$booking) {
                return redirect()->back()->with('error', 'Booking not found.');
            }

            $customer = DB::table('customers')->where('id', $booking->customer_id)->first();
            if (!$customer) {
                return redirect()->back()->with('error', 'Customer not found.');
            }

            // Update the customer details
            DB::table('customers')
                ->where('id', $booking->customer_id)
                ->update([
                    'title' => $validatedData['title'],
                    'first_name' => $validatedData['name'],
                    'last_name' => $validatedData['name'],
                    'mobile' => $validatedData['mobile'],
                    'email' => $validatedData['email'],
                    'updated_at' => Carbon::now(),
                ]);

            // Update the booking details
            $bookingData = [
                'company_id' => $validatedData['agent'],
                'airport_id' => $validatedData['airport'],
                'product_id' => $validatedData['product'],
                'price' => $validatedData['price'],
                'net_price' => $validatedData['price'],
                'total_amount' => $validatedData['price'],
                'status' => 'pending',
                'date_from' => $validatedData['datetimepicker_departure'],
                'date_to' => $validatedData['datetimepicker_return'],
                'updated_at' => Carbon::now(),
            ];
            DB::table('bookings')
                ->where('id', $id)
                ->update($bookingData);

            // Update the vehicle details
            DB::table('vehicles')
                ->where('booking_id', $id)
                ->update([
                    'vehicle_no' => $validatedData['reg_no'],
                    'vehicle_make' => $validatedData['make_model'],
                    'vehicle_model' => $validatedData['make_model'],
                    'vehicle_color' => $validatedData['colour'],
                    'updated_at' => Carbon::now(),
                ]);

            // Commit the transaction
            DB::commit();

            // Success response or redirect
            return redirect()->back()->with('success', 'Booking updated successfully!');
        } catch (\Exception $e) {
            // Rollback the transaction on failure
            DB::rollBack();

            // Return error response or redirect
            return redirect()->back()->with('error', 'An error occurred while updating data.');
        }
    }
}
