<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Company extends Model
{
    use HasFactory, SoftDeletes;

    protected $dates = ['deleted_at']; // Ensure `deleted_at` is treated as a date

    protected $fillable = [
        'name',
        'register_number',
        'vat_number',
        'address',
        'country',
        'currency',
        'currency_symbol',
        'mobile',
        'phone',
        'company_logo',
        'email',
        'street',
        'city',
        'country',
        'postal_code',
        'hotline_1',
        'hotline_2',
        'booking_email',
        'password',
        'company_email',
        'website',
        'logo'
    ];

    // Add basic validation rules
    public static $rules = [
        'name' => 'required|string|max:255',
        'register_number' => 'required|string|max:255',
        'vat_number' => 'required|string|max:255',
        'address' => 'required|string|max:255',
        'street' => 'required|string|max:255',
        'city' => 'required|string|max:255',
        'country' => 'required|string|max:255',
        'postal_code' => 'required|string|max:255',
        'hotline_1' => 'required|string|max:255',
        'hotline_2' => 'nullable|string|max:255',
        'booking_email' => 'required|email|max:255',
        'password' => 'nullable|string|min:8',
        'company_email' => 'required|email|max:255',
        'website' => 'required|string|max:255',
        'logo' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
    ];

    protected function logo(): Attribute
    {
        return Attribute::make(
            get: fn (string $value) =>   $value ? asset('storage/images/'.$value) : null,
        );
    }

    public function formatResponse($company) : array
    {
        return [
            'name' => $company->name,
            'address' => $company->address,
            'country' => $company->country,
            'currency' => $company->currency,
            'currency_symbol' => $company->currency_symbol,
            'mobile' => $company->mobile,
            'phone' => $company->phone,
            'logo' => $company->logo,
            'email' => $company->email,
        ];
    }
}
