<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class Product extends Model
{
    use HasFactory;

    protected $fillable = [
        'name',
        'subtitle',
        'featured_image',
        'terms_and_conditions',
        'description',
        'drop_off_procedure',
        'pick_up_procedure',
        'min_dates',
        'max_dates',
        'company_id',
        'airport_id',
        'price',
        'quantity',
        'feature_ids',
        'service_ids'
    ];

    protected $casts = [
        'min_dates' => 'integer',
        'max_dates' => 'integer'
    ];

    protected $with = ['company'];

    // Validation rules
    public static $rules = [
        'name' => 'required|string|max:150',
        'featured_image' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        'terms_and_conditions' => 'required|string',
        'description' => 'required|string',
        'drop_off_procedure' => 'required|string',
        'pick_up_procedure' => 'required|string',
        'min_dates' => 'required|integer|min:1',
        'max_dates' => 'required|integer|min:1|gte:min_dates',
        'company_id' => 'required|exists:companies,id'
    ];

    protected function casts(): array
    {
        return [
//            'description' => 'array',
        ];
    }

    protected function featuredImage(): Attribute
    {
        return Attribute::make(
            get: fn (string $value) =>  asset('storage/images/'.$value),
        );
    }

    public function formatResponse($product): array
    {
        return [
            'product_name' => $product->name,
            'subtitle' => $product->subtitle,
            'featured_image' => $product->featured_image,
            'terms_and_conditions' => $product->terms_and_conditions,
            'description' => $product->description,
            'drop_off_procedure' => $product->drop_off_procedure,
            'pick_up_procedure' => $product->pick_up_procedure,
            'min_dates' => $product->min_dates,
            'max_dates' => $product->max_dates,
            //'company' => $product->company,
        ];
    }

    public function company()
    {
        return $this->belongsTo(Company::class);
    }

    public function imageAttribute()
    {
        return asset('storage/images/'.$this->featured_image);
    }

}
