<?php

namespace App\Services;

use Stripe\Checkout\Session;
use Stripe\Stripe;
use Stripe\PaymentIntent;
use Stripe\Customer;
use Stripe\Exception\ApiErrorException;
use Stripe\Webhook;

class StripeService
{
    public function __construct()
    {
        Stripe::setApiKey(config('services.stripe.secret'));
    }

    public function createCustomer(string $email, string $name)
    {
        try {
            return Customer::create([
                'email' => $email,
                'name' => $name
            ]);
        } catch (ApiErrorException $e) {
            return ['error' => $e->getMessage()];
        }
    }

    public function createPaymentIntent($data)
    {
        try {

            $session = Session::create([
                'metadata' => ['booking_id' => $data['booking_id']],
                //'payment_method_types' => ['card'],
                'line_items' => [[
                    'price_data' => [
                        'currency' => $data['payment_currency'] ?? config('services.stripe.currency'),
                        'product_data' => ['name' => 'Your Product Name'],
                        'unit_amount' => $data['payment_amount'], // Amount in cents ($10.00)
                    ],
                    'quantity' => 1,
                ]],
                'mode' => 'payment',
                'payment_method_types' => ['card'], //apple_pay


                'success_url' => route('stripe.checkout.success') . '?session_id={CHECKOUT_SESSION_ID}',
                'cancel_url' => route('stripe.checkout.cancel'),
            ]);

            return $session;

        } catch (ApiErrorException $e) {
            return ['error' => $e->getMessage()];
        }
    }

    public function webhookData($payload, $signature, $secret)
    {
        return Webhook::constructEvent($payload, $signature, $secret);
    }
}
