$(document).ready(function () {
    var form = $('#companyAdd');
    var loader = $('#addLoader');
    var isEditMode = false; // Flag to check if we're in edit mode
    var companyId = null; // Variable to store the company ID in edit mode

    // Function to handle form submission
    form.on('submit', function (e) {
        e.preventDefault(); // Prevent the default form submission

        if (isEditMode) {
            // Show the confirmation modal for update
            $('#confirmUpdateModal').modal('show');
        } else {
            // If not in edit mode, submit the form directly (create mode)
            submitForm();
        }
    });

    // Handle the confirmation button click
    $('#confirmUpdateButton').on('click', function () {
        $('#confirmUpdateModal').modal('hide'); // Hide the modal
        submitForm(); // Proceed with the form submission
    });

    // Function to submit the form
    function submitForm() {
        loader.addClass('active');
        var formData = new FormData(form[0]); // Create a FormData object

        if (isEditMode) {
            formData.append('_method', 'PUT'); // Override method to PUT
        }

        // Determine the URL and HTTP method based on edit mode
        var url = isEditMode ? `/company/${companyId}` : companyStoreRoute;
        var method = 'POST';

        $.ajax({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            },
            url: url, // Route to handle the form submission
            type: method,
            data: formData,
            processData: false,
            contentType: false,
            success: function (response) {
                toastr.success(response.message);
                loader.removeClass('active');
                form[0].reset(); // Reset the form

                form.removeClass('was-validated');
                form.find('.form-control').removeClass('is-invalid');
                form.find('.form-control').removeClass('is-valid');

                $('#companies-table').DataTable().ajax.reload(); // Reload the table
            },
            error: function (xhr) {
                if (xhr.status === 422) {
                    var errors = xhr.responseJSON.errors;
                    if (errors) {
                        $.each(errors, function (key, value) {
                            toastr.error(value); // Display each error message
                        });
                    }
                } else {
                    // Handle generic errors
                    toastr.error(xhr.responseJSON.message || 'An error occurred. Please try again.');
                }
                loader.removeClass('active');
            }
        });
    }

    // Edit button click event
    $('#companies-table').on('click', '.edit-company-btn', function () {
        isEditMode = true; // Set edit mode to true
        companyId = $(this).data('id'); // Get the company ID from the button

        // Fetch company data
        $.ajax({
            url: `/company/${companyId}/edit`,
            method: 'GET',
            success: function (response) {
                // Populate the form with the fetched data
                $('#companyName').val(response.company.name);
                $('#registerNo').val(response.company.register_number);
                $('#vatNo').val(response.company.vat_number);
                $('#address').val(response.company.address);
                $('#street').val(response.company.street);
                $('#city').val(response.company.city);
                $('#country').val(response.company.country);
                $('#postalCode').val(response.company.postal_code);
                $('#hotline1').val(response.company.hotline_1);
                $('#hotline2').val(response.company.hotline_2);
                $('#bookingEmail').val(response.company.booking_email);
                $('#password').val(''); // Password is not fetched for security reasons
                $('#companyEmail').val(response.company.company_email);
                $('#website').val(response.company.website);

                // Add a hidden input for company ID if it doesn't exist
                if (!$('#companyId').length) {
                    form.append('<input type="hidden" id="companyId" name="id" />');
                }
                $('#companyId').val(companyId); // Set the company ID in the hidden field

                // Scroll to the form
                $('html, body').animate({
                    scrollTop: $('#companyAdd').offset().top
                }, 1000);
            },
            error: function (xhr) {
                toastr.error('An error occurred while fetching company details.');
            }
        });
    });

    var deleteCompanyId = null; // Variable to store the company ID for deletion

    // Delete button click event
    $('#companies-table').on('click', '.delete-company-btn', function () {
        deleteCompanyId = $(this).data('id'); // Get the company ID from the button
        $('#confirmDeleteModal').modal('show'); // Show the confirmation modal
    });

    // Handle the confirmation button click
    $('#confirmDeleteButton').on('click', function () {
        $('#confirmDeleteModal').modal('hide'); // Hide the modal

        // Send the delete request
        $.ajax({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            },
            url: `/company/${deleteCompanyId}`, // Endpoint to delete the company
            type: 'DELETE',
            success: function (response) {
                toastr.success(response.message);
                $('#companies-table').DataTable().ajax.reload(); // Reload the table
            },
            error: function (xhr) {
                toastr.error(xhr.responseJSON.message || 'An error occurred while deleting the company.');
            }
        });
    });
});
