$(document).ready(function () {
    var form = $('#productAdd');
    var loader = $('#addLoader');
    var isEditMode = false;
    var productId = null;

    // Function to handle form submission
    form.on('submit', function (e) {
        e.preventDefault(); // Prevent the default form submission

        if (isEditMode) {
            // Show the confirmation modal for update
            $('#confirmUpdateModal').modal('show');
        } else {
            // If not in edit mode, submit the form directly (create mode)
            submitForm();
        }
    });

    // Handle the confirmation button click
    $('#confirmUpdateButton').on('click', function () {
        $('#confirmUpdateModal').modal('hide'); // Hide the modal
        submitForm(); // Proceed with the form submission
    });

    function submitForm() {
        loader.addClass('active');
        var formData = new FormData(form[0]); // Create a FormData object

        if (isEditMode) {
            formData.append('_method', 'PUT'); // Override method to PUT
        }

        var url = isEditMode ? `/product/${productId}` : productStoreRoute;
        var method = 'POST';

        $.ajax({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            },
            url: url, // Route to handle the form submission
            type: method,
            data: formData,
            processData: false,
            contentType: false,
            success: function (response) {
                toastr.success(response.message);
                loader.removeClass('active');
                form[0].reset(); // Reset the form

                form.removeClass('was-validated');
                form.find('.form-control').removeClass('is-invalid');
                form.find('.form-control').removeClass('is-valid');

                $('#products-table').DataTable().ajax.reload();
                $('#features').val([]).trigger('change');
                $('#services').val([]).trigger('change');
            },
            error: function (xhr) {
                loader.removeClass('active');
                if (xhr.status === 422) {
                    var errors = xhr.responseJSON.errors;
                    if (errors) {
                        $.each(errors, function (key, value) {
                            toastr.error(value); // Display each error message
                        });
                    }
                } else {
                    // Handle generic errors
                    toastr.error(xhr.responseJSON.message || 'An error occurred. Please try again.');
                }
                $('#features').val([]).trigger('change');
                $('#services').val([]).trigger('change');
            }
        });
    }

    // Edit button click event
    $('#products-table').on('click', '.edit-product-btn', function () {
        isEditMode = true; // Set edit mode to true
        productId = $(this).data('id'); // Get the company ID from the button

        // Fetch company data
        $.ajax({
            url: `/product/${productId}/edit`,
            method: 'GET',
            success: function (response) {
                // Populate the form with the fetched data
                $('#productName').val(response.data.product.name);
                $('#minDates').val(response.data.product.min_dates);
                $('#maxDates').val(response.data.product.max_dates);
                $('#company').val(response.data.product.company_id);
                $('#description').val(response.data.product.description);
                $('#dropOffProcedure').val(response.data.product.drop_off_procedure);
                $('#pickUpProcedure').val(response.data.product.pick_up_procedure);
                $('#termsAndConditions').val(response.data.product.terms_and_conditions);
                $('#airportId').val(response.data.airport_product.airport_id);
                $('#price').val(response.data.airport_product.price);
                $('#quantity').val(response.data.airport_product.available_quantity);

                var isActive = response.data.airport_product.is_active ? 1 : 0;
                $('#isActive').val(isActive);

                let features = JSON.parse(response.data.product.feature_ids);
                let services = JSON.parse(response.data.product.service_ids);

                $('#features').val(features).trigger('change');
                $('#services').val(services).trigger('change');

                // Add a hidden input for company ID if it doesn't exist
                if (!$('#productId').length) {
                    form.append('<input type="hidden" id="productId" name="id" />');
                }
                $('#productId').val(productId);

                // Scroll to the form
                $('html, body').animate({
                    scrollTop: $('#productAdd').offset().top
                }, 1000);
            },
            error: function (xhr) {
                toastr.error('An error occurred while fetching product details.');
            }
        });
    });

    var deleteProductId = null; // Variable to store the company ID for deletion

    // Delete button click event
    $('#products-table').on('click', '.delete-product-btn', function () {
        deleteProductId = $(this).data('id'); // Get the company ID from the button
        $('#confirmDeleteModal').modal('show'); // Show the confirmation modal
    });

    // Handle the confirmation button click
    $('#confirmDeleteButton').on('click', function () {
        $('#confirmDeleteModal').modal('hide'); // Hide the modal

        // Send the delete request
        $.ajax({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            },
            url: `/product/${deleteProductId}`, // Endpoint to delete the company
            type: 'DELETE',
            success: function (response) {
                toastr.success(response.message);
                $('#products-table').DataTable().ajax.reload(); // Reload the table
            },
            error: function (xhr) {
                toastr.error(xhr.responseJSON.message || 'An error occurred while deleting the company.');
            }
        });
    });

    // Initialize Select2
    $('#features').select2({
        placeholder: "Select features",
        allowClear: true,
    });

    $('#services').select2({
        placeholder: "Select services",
        allowClear: true,
    });
});
