@extends('backend.layouts.app')

@section('title', $title)

@section('content')
    <div class="app-content-header">
        <div class="container-fluid">
            <div class="row">
                <div class="col-sm-6"><h3 class="mb-0">{{ ucwords($title) }}</h3></div>
            </div>
        </div>
    </div>
    <div class="app-content">
        <div class="container-fluid">
            <div class="row">
                <div class="col-12 col-sm-12 col-md-12">
                    <div class="card card-info card-outline mb-4">
                        <form class="needs-validation" novalidate method="POST" enctype="multipart/form-data"
                              id="airportAdd">
                            @csrf
                            <input type="hidden" id="airportId" name="id"/>
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-4">
                                        <label for="airportName" class="form-label">Airport name</label>
                                        <input
                                            type="text"
                                            class="form-control form-control-sm"
                                            id="airportName"
                                            name="name"
                                            required
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>
                                    <div class="col-md-4">
                                        <label for="country" class="form-label">Country</label>
                                        <input
                                            type="text"
                                            class="form-control form-control-sm"
                                            id="country"
                                            name="country"
                                            required
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>
                                    <div class="col-md-4">
                                        <label for="address" class="form-label">Address</label>
                                        <input
                                            type="text"
                                            class="form-control form-control-sm"
                                            id="address"
                                            name="address"
                                            required
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>
                                    <div class="col-md-4">
                                        <label for="email" class="form-label">Email</label>
                                        <input
                                            type="email"
                                            class="form-control form-control-sm"
                                            id="email"
                                            name="email"
                                            required
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>
                                    <div class="col-md-4">
                                        <label for="latitude" class="form-label">Latitude</label>
                                        <input
                                            type="number"
                                            class="form-control form-control-sm"
                                            id="latitude"
                                            name="latitude"
                                            required
                                            step="0.00000001"
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>
                                    <div class="col-md-4">
                                        <label for="longitude" class="form-label">Longitude</label>
                                        <input
                                            type="number"
                                            class="form-control form-control-sm"
                                            id="longitude"
                                            name="longitude"
                                            required
                                            step="0.00000001"
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>

                                    <div class="col-md-4">
                                        <label for="status" class="form-label">Status</label>
                                        <select class="form-select form-select-sm" id="status" name="status" required>
                                            <option selected value=1>Active</option>
                                            <option value=0>Deactive</option>
                                        </select>
                                        <div class="invalid-feedback">Please select a valid status.</div>
                                    </div>
                                </div>
                            </div>
                            <div class="card-footer">
                                <button class="btn btn-info float-end" type="submit">Save</button>
                            </div>
                            <!-- Loader Overlay -->
                            <div class="card-overlay" id="addLoader">
                                <div class="spinner-border text-success" role="status">
                                    <span class="visually-hidden">Loading...</span>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>

            <div class="row">
                <div class="col-md-12">
                    <div class="card mb-4">
                        <div class="card-body" style="overflow: auto;">
                            {{ $dataTable->table() }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <x-update-confirmation-modal
        message="Are you sure you want to airport this airport?"
    />
    <x-delete-confirmation-modal
        message=" Are you sure you want to delete this airport? This action cannot be undone."
    />
@endsection

@push('scripts')
    <script>
        const airportStoreRoute = "{{ route('airport.store') }}";
    </script>
    <script src="{{ asset('js/settings/setting.js') }}"></script>
    <script src="{{ asset('js/settings/airport.js') }}"></script>
    {{--    {{ $dataTable->scripts(attributes: ['type' => 'module']) }}--}}
    <script type="module">$(function () {
            window.LaravelDataTables = window.LaravelDataTables || {};
            window.LaravelDataTables["airports-table"] = $("#airports-table").DataTable({
                "serverSide": true,
                "processing": true,
                "ajax": {
                    "url": "{{route('airport.index')}}", "type": "GET", "data": function (data) {
                        for (var i = 0, len = data.columns.length; i < len; i++) {
                            if (!data.columns[i].search.value) delete data.columns[i].search;
                            if (data.columns[i].searchable === true) delete data.columns[i].searchable;
                            if (data.columns[i].orderable === true) delete data.columns[i].orderable;
                            if (data.columns[i].data === data.columns[i].name) delete data.columns[i].name;
                        }
                        delete data.search.regex;
                    }
                },
                "columns": [{
                    "data": "#",
                    "name": "#",
                    "title": "#",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "name",
                    "name": "name",
                    "title": "Name",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "country",
                    "name": "country",
                    "title": "Country",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "address",
                    "name": "address",
                    "title": "Address",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "email",
                    "name": "email",
                    "title": "Email",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "latitude",
                    "name": "latitude",
                    "title": "Latitude",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "longitude",
                    "name": "longitude",
                    "title": "Longitude",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "status",
                    "name": "status",
                    "title": "Status",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "action",
                    "name": "action",
                    "title": "Action",
                    "orderable": false,
                    "searchable": false,
                    "width": 60,
                    "className": "text-center"
                }],
                "order": [[1, "desc"]],
                "select": {"style": "single"},
                "buttons": [{"extend": "excel"}, {"extend": "csv"}, {"extend": "pdf"}, {"extend": "print"}]
            });
        });</script>

@endpush

@push('styles')
    <link rel="stylesheet" href="{{ asset('css/datatables-custom.css') }}"/>
@endpush
