@extends('backend.layouts.app')

@section('title', $title)

@section('content')
    <div class="app-content-header">
        <div class="container-fluid">
            <div class="row">
                <div class="col-sm-6"><h3 class="mb-0">{{ ucwords($title) }}</h3></div>
            </div>
        </div>
    </div>
    <div class="app-content">
        <div class="container-fluid">
            <div class="row">
                <div class="col-12 col-sm-12 col-md-12">
                    <div class="card card-info card-outline mb-4">
                        <form class="needs-validation" novalidate method="POST" enctype="multipart/form-data"
                              id="blockAdd">
                            @csrf
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-4">
                                        <label for="blockName" class="form-label">Block name</label>
                                        <input
                                            type="text"
                                            class="form-control form-control-sm"
                                            id="blockName"
                                            name="name"
                                            required
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>
                                    <div class="col-md-4">
                                        <label for="latitude" class="form-label">Latitude</label>
                                        <input
                                            type="number"
                                            class="form-control form-control-sm"
                                            id="latitude"
                                            name="latitude"
                                            required
                                            step="0.00000001"
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>
                                    <div class="col-md-4">
                                        <label for="longitude" class="form-label">Longitude</label>
                                        <input
                                            type="number"
                                            class="form-control form-control-sm"
                                            id="longitude"
                                            name="longitude"
                                            required
                                            step="0.00000001"
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>
                                    <div class="col-md-4">
                                        <label for="capacity" class="form-label">Capacity</label>
                                        <input
                                            type="number"
                                            class="form-control form-control-sm"
                                            id="capacity"
                                            name="capacity"
                                            required
                                            step="1"
                                            min="0"
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>
                                    <div class="col-md-4">
                                        <label for="site" class="form-label">Site</label>
                                        <select class="form-select form-select-sm" id="site" name="site_id" required>
                                            <option selected value="">Select Site</option>
                                            @foreach($sites as $site)
                                                <option value="{{ $site->id }}">{{ $site->name }}</option>
                                            @endforeach
                                        </select>
                                        <div class="invalid-feedback">Please select a valid site.</div>
                                    </div>
                                </div>
                            </div>
                            <div class="card-footer">
                                <button class="btn btn-info float-end" type="submit">Save</button>
                            </div>
                            <!-- Loader Overlay -->
                            <div class="card-overlay" id="addLoader">
                                <div class="spinner-border text-success" role="status">
                                    <span class="visually-hidden">Loading...</span>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>

            <div class="row">
                <div class="col-md-12">
                    <div class="card mb-4">
                        <div class="card-body" style="overflow: auto;">
                            {{ $dataTable->table() }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <x-update-confirmation-modal
        message="Are you sure you want to update this block?"
    />
    <x-delete-confirmation-modal
        message=" Are you sure you want to delete this block? This action cannot be undone."
    />
@endsection

@push('scripts')
    <script>
        const blockStoreRoute = "{{ route('block.store') }}";
    </script>
    <script src="{{ asset('js/settings/setting.js') }}"></script>
    <script src="{{ asset('js/settings/block.js') }}"></script>
    {{--    {{ $dataTable->scripts(attributes: ['type' => 'module']) }}--}}
    <script type="module">$(function () {
            window.LaravelDataTables = window.LaravelDataTables || {};
            window.LaravelDataTables["blocks-table"] = $("#blocks-table").DataTable({
                "serverSide": true,
                "processing": true,
                "ajax": {
                    "url": "{{route('block.index')}}", "type": "GET", "data": function (data) {
                        for (var i = 0, len = data.columns.length; i < len; i++) {
                            if (!data.columns[i].search.value) delete data.columns[i].search;
                            if (data.columns[i].searchable === true) delete data.columns[i].searchable;
                            if (data.columns[i].orderable === true) delete data.columns[i].orderable;
                            if (data.columns[i].data === data.columns[i].name) delete data.columns[i].name;
                        }
                        delete data.search.regex;
                    }
                },
                "columns": [{
                    "data": "#",
                    "name": "#",
                    "title": "#",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "name",
                    "name": "name",
                    "title": "Name",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "latitude",
                    "name": "latitude",
                    "title": "Latitude",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "longitude",
                    "name": "longitude",
                    "title": "Longitude",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "capacity",
                    "name": "capacity",
                    "title": "Capacity",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "site.name",
                    "name": "site.name",
                    "title": "Site Name",
                    "orderable": true,
                    "searchable": true
                }, {
                    "data": "action",
                    "name": "action",
                    "title": "Action",
                    "orderable": false,
                    "searchable": false,
                    "width": 60,
                    "className": "text-center"
                }],
                "order": [[1, "desc"]],
                "select": {"style": "single"},
                "buttons": [{"extend": "excel"}, {"extend": "csv"}, {"extend": "pdf"}, {"extend": "print"}]
            });
        });</script>

@endpush

@push('styles')
    <link rel="stylesheet" href="{{ asset('css/datatables-custom.css') }}"/>
@endpush
