@extends('backend.layouts.app')

@section('title', $title)

@push('styles')
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" rel="stylesheet">

    <!-- Select2 Bootstrap Theme CSS (for better integration with Bootstrap) -->
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <!-- Date Range Picker CSS -->
    <link href="https://cdn.jsdelivr.net/npm/daterangepicker/daterangepicker.css" rel="stylesheet" />
    <!-- DataTables CSS -->
    <link href="https://cdn.datatables.net/1.11.5/css/dataTables.bootstrap5.min.css" rel="stylesheet" />
    <!-- DataTables Buttons CSS -->
    <link href="https://cdn.datatables.net/buttons/2.2.3/css/buttons.bootstrap5.min.css" rel="stylesheet" />
    <!-- DataTables Responsive CSS -->
    <link href="https://cdn.datatables.net/responsive/2.2.9/css/responsive.bootstrap5.min.css" rel="stylesheet" />
    <!-- FontAwesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <!-- flatpickr CSS -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/flatpickr/dist/flatpickr.min.css">

@endpush

@section('content')
    <!--begin::App Main-->
    <main class="app-main">
        <!--begin::App Content Header-->
        <div class="app-content-header">
            <!--begin::Container-->
            <div class="container-fluid">
                <!--begin::Row-->
                <div class="row">
                    <div class="col-sm-6"><h3 class="mb-0">{{$title}}</h3></div>
                </div>
                <!--end::Row-->
            </div>
            <!--end::Container-->
        </div>
        <!--end::App Content Header-->
        <!--begin::App Content-->
        <div class="app-content">
            <!--begin::Container-->
            <div class="container-fluid">
                <!--begin::Row-->
                <div class="row">


                    @if(session('success'))
                        <div class="alert alert-success alert-dismissible fade show" role="alert">
                            {{ session('success') }}
                            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                        </div>
                    @endif
                    @if(session('error'))
                        <div class="alert alert-danger alert-dismissible fade show" role="alert">
                            {{ session('error') }}
                            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                        </div>
                    @endif

                    <!--begin::Form-->
                    <form action="{{ $booking ? route('booking.update', $booking->id) : route('booking.store') }}" method="POST">
                        @csrf
                        @if($booking)
                            @method('PUT')
                        @endif
                        <div class="card card-primary card-outline mb-4">
                            <div class="card-header"><div class="card-title">Back office booking form</div></div>
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="card-body">
                                        <!-- Product Dropdown -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="product">Product *</label>
                                                <select class="form-control form-control-sm @error('product') is-invalid @enderror" id="product" name="product">
                                                    <option value="">Please select</option>
                                                    @foreach($products as $product)
                                                        <option value="{{$product->id}}" {{ ($booking && $booking->product_id == $product->id) ? 'selected' : '' }}>{{$product->name}}</option>
                                                    @endforeach
                                                </select>
                                                @error('product')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Agent Dropdown -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="agent">Agent *</label>
                                                <select class="form-control form-control-sm @error('agent') is-invalid @enderror" id="agent" name="agent">
                                                    <option value="">Please select</option>
                                                    @foreach($company as $agent)
                                                        <option value="{{$agent->id}}" {{ ($booking && $booking->company_id == $agent->id) ? 'selected' : '' }}>{{$agent->name}}</option>
                                                    @endforeach
                                                </select>
                                                @error('agent')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Reference Number -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="ref_no">Ref No *</label>
                                                <input type="text" class="form-control form-control-sm @error('ref_no') is-invalid @enderror" id="ref_no" name="ref_no" value="{{ $booking->ref_no ?? old('ref_no') }}">
                                                @error('ref_no')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Airport Dropdown -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="airport">Airport *</label>
                                                <select class="form-control form-control-sm @error('airport') is-invalid @enderror" id="airport" name="airport">
                                                    <option value="">Please select</option>
                                                    @foreach($airports as $airport)
                                                        <option value="{{$airport->id}}" {{ ($booking && $booking->airport_id == $airport->id) ? 'selected' : '' }}>{{$airport->name}}</option>
                                                    @endforeach
                                                </select>
                                                @error('airport')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Departure Date and Time -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="datetimepicker_departure">Departure Date and Time *</label>
                                                <input type="datetime-local" class="form-control form-control-sm @error('datetimepicker_departure') is-invalid @enderror" id="datetimepicker_departure" name="datetimepicker_departure" value="{{ $booking ? $booking->date_from : old('datetimepicker_departure') }}">
                                                @error('datetimepicker_departure')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="col-md-6">
                                    <div class="card-body">
                                        <!-- Terminal In Dropdown -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="terminal_in">Terminal In *</label>
                                                <select class="form-control form-control-sm @error('terminal_in') is-invalid @enderror" id="terminal_in" name="terminal_in">
                                                    <option value="">Please select</option>
                                                    <option value="1">test</option>

                                                    @foreach($terminals as $terminal)
                                                        <option value="{{$terminal->id}}" {{ ($booking && $booking->terminal_in_id == $terminal->id) ? 'selected' : '' }}>{{$terminal->terminal_name}}</option>
                                                    @endforeach

                                                </select>
                                                @error('terminal_in')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Terminal Out Dropdown -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="terminal_out">Terminal Out *</label>
                                                <select class="form-control form-control-sm @error('terminal_out') is-invalid @enderror" id="terminal_out" name="terminal_out">
                                                    <option value="">Please select</option>
                                                    <option value="1">test</option>

                                                    @foreach($terminals as $terminal)
                                                        <option value="{{$terminal->id}}" {{ ($booking && $booking->terminal_out_id == $terminal->id) ? 'selected' : '' }}>{{$terminal->terminal_name}}</option>
                                                    @endforeach

                                                </select>
                                                @error('terminal_out')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Departure Flight -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="departure_flight">Departure Flight *</label>
                                                <input type="text" class="form-control form-control-sm @error('departure_flight') is-invalid @enderror" id="departure_flight" name="departure_flight" value="{{ $booking->departure_flight ?? old('departure_flight') }}">
                                                @error('departure_flight')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Return Flight -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="return_flight">Return Flight *</label>
                                                <input type="text" class="form-control form-control-sm @error('return_flight') is-invalid @enderror" id="return_flight" name="return_flight" value="{{ $booking->return_flight ?? old('return_flight') }}">
                                                @error('return_flight')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Price -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="price">Price *</label>
                                                <input type="text" class="form-control form-control-sm @error('price') is-invalid @enderror" id="price" name="price" value="{{ $booking ? $booking->price : old('price') }}">
                                                @error('price')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Return Date and Time -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="datetimepicker_return">Return Date and Time *</label>
                                                <input type="datetime-local" class="form-control form-control-sm @error('datetimepicker_return') is-invalid @enderror" id="datetimepicker_return" name="datetimepicker_return" value="{{ $booking ? $booking->date_to : old('datetimepicker_return') }}">
                                                @error('datetimepicker_return')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <!-- Contact & Vehicle Information -->
                        <div class="card card-success card-outline mb-4">
                            <div class="card-header"><div class="card-title">Contact & Vehicle Information</div></div>
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="card-body">
                                        <!-- Title Dropdown -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="title">Title *</label>
                                                <select class="form-control form-control-sm @error('title') is-invalid @enderror" id="title" name="title">
                                                    <option value="">Please select</option>
                                                    @foreach($user_title as $key => $title)
                                                        <option value="{{$key}}" {{ ($customer && $customer->title == $key) ? 'selected' : '' }}>{{$title}}</option>
                                                    @endforeach
                                                </select>
                                                @error('title')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Name -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="name">Name *</label>
                                                <input type="text" class="form-control form-control-sm @error('name') is-invalid @enderror" id="name" name="name" value="{{ $customer ? $customer->first_name : old('name') }}">
                                                @error('name')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Email -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="email">Email *</label>
                                                <input type="email" class="form-control form-control-sm @error('email') is-invalid @enderror" id="email" name="email" value="{{ $customer ? $customer->email : old('email') }}">
                                                @error('email')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Mobile -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="mobile">Mobile *</label>
                                                <input type="text" class="form-control form-control-sm @error('mobile') is-invalid @enderror" id="mobile" name="mobile" value="{{ $customer ? $customer->mobile : old('mobile') }}">
                                                @error('mobile')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="col-md-6">
                                    <div class="card-body">
                                        <!-- Make & Model -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="make_model">Make & Model *</label>
                                                <input type="text" class="form-control form-control-sm @error('make_model') is-invalid @enderror" id="make_model" name="make_model" value="{{ $vehicle ? $vehicle->vehicle_make : old('make_model') }}">
                                                @error('make_model')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Registration Number -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="reg_no">Reg No *</label>
                                                <input type="text" class="form-control form-control-sm @error('reg_no') is-invalid @enderror" id="reg_no" name="reg_no" value="{{ $vehicle ? $vehicle->vehicle_no : old('reg_no') }}">
                                                @error('reg_no')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Colour -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="colour">Colour *</label>
                                                <input type="text" class="form-control form-control-sm @error('colour') is-invalid @enderror" id="colour" name="colour" value="{{ $vehicle ? $vehicle->vehicle_color : old('colour') }}">
                                                @error('colour')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Number of Passengers -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="passengers">No of passengers *</label>
                                              <input type="number" class="form-control form-control-sm @error('passengers') is-invalid @enderror" id="passengers" name="passengers" value="{{  old('passengers') }}"> {{--  $booking ? $booking->passengers :--}}
                                                @error('passengers')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>

                                        <!-- Note -->
                                        <div class="mb-3">
                                            <div class="form-group">
                                                <label class="form-label col-form-label-sm" for="note">Note</label>
                                                <textarea class="form-control form-control-sm @error('note') is-invalid @enderror" rows="3" id="note" name="note">{{  old('note') }}</textarea> {{--$booking ? $booking->note :--}}
                                                @error('note')
                                                <span class="invalid-feedback" role="alert">
                                                    <strong>{{ $message }}</strong>
                                                </span>
                                                @enderror
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <!-- Footer -->
                            <div class="card-footer">
                                <button type="submit" class="btn btn-success">{{ $booking ? 'Update' : 'Save' }} Booking</button>
                                <button type="reset" class="btn btn-warning float-end">Reset</button>
                            </div>
                        </div>
                    </form>
                    <!--end::Form-->
                </div>
                <!-- /.row (main row) -->
            </div>
            <!--end::Container-->
        </div>
        <!--end::App Content-->
    </main>
    <!--end::App Main-->
@endsection

@section('scripts')
    <!-- Select2 JS -->
    <script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
    <!-- Bootstrap 5 JS -->
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/5.1.3/js/bootstrap.bundle.min.js"></script>
    <!-- Moment.js (required for Date Range Picker) -->
    <script src="https://cdn.jsdelivr.net/momentjs/latest/moment.min.js"></script>
    <!-- Date Range Picker JS -->
    <script src="https://cdn.jsdelivr.net/npm/daterangepicker/daterangepicker.min.js"></script>
    <!-- DataTables JS -->
    <script src="https://cdn.datatables.net/1.11.5/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.5/js/dataTables.bootstrap5.min.js"></script>
    <!-- DataTables Buttons JS -->
    <script src="https://cdn.datatables.net/buttons/2.2.3/js/dataTables.buttons.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.2.3/js/buttons.bootstrap5.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.1.3/jszip.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.2.3/js/buttons.html5.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.2.3/js/buttons.print.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.2.3/js/buttons.colVis.min.js"></script>
    <!-- DataTables Responsive JS -->
    <script src="https://cdn.datatables.net/responsive/2.2.9/js/dataTables.responsive.min.js"></script>
    <script src="https://cdn.datatables.net/responsive/2.2.9/js/responsive.bootstrap5.min.js"></script>
    <!-- flatpickr JS -->
    <script src="https://cdn.jsdelivr.net/npm/flatpickr"></script>

    <script>
        $(document).ready(function () {
            $('#datetimepicker_departure').flatpickr({
                enableTime: true,  // Enables time selection
                dateFormat: "Y-m-d H:i",  // Format for date and time
                defaultDate: null // Optionally set a default date
            });
            $('#datetimepicker_return').flatpickr({
                enableTime: true,  // Enables time selection
                dateFormat: "Y-m-d H:i",  // Format for date and time
                defaultDate: null // Optionally set a default date
            });

        });


        $(document).ready(function() {
            $('.select2').select2({
                theme: 'bootstrap-5'
            });

            // Initialize Date Range Picker
            $('#daterange').daterangepicker({
                locale: {
                    format: 'YYYY-MM-DD'
                },
                startDate: moment().subtract(29, 'days'),
                endDate: moment()
            });

            // Set the CSRF token in the AJAX header
            $.ajaxSetup({
                headers: {
                    'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                }
            });

            $.ajax({
                url: '{{ route("booking.store") }}',  // Route to hit the controller
                type: 'POST',  // Request type (GET or POST)
                success: function (response) {console(response);
                    if (response.success) {
                        // Populate dropdown with products data or display success message
                        let productDropdown = $('#productDropdown');  // Assuming you have a dropdown with id productDropdown
                        productDropdown.empty();  // Clear existing options
                        $.each(response.data, function (key, product) {
                            productDropdown.append('<option value="' + product.id + '">' + product.name + '</option>');
                        });
                    }
                },
                error: function (error) {
                    // Handle any errors
                    console.log('Error:', error);
                }
            });

        });
    </script>
@endsection
