@extends('layouts.app')

@section('title', 'Holiday Parking - What We Offer')

@section('content')
    @include('partials.header', ['title' =>  __('pages.about.title')])

    <section class="text-fontBase font-poppins">

        <!-- Flex Container -->
        <div class="w-full flex items-center mx-auto py-8 md:py-12" >
            <!-- Flex container -->
            <div class="container flex flex-col-reverse space-y-6 md:flex-row md:space-y-0 md:space-x-3 py-4 px-4 md:px-0 mx-auto justify-center">
                <!-- Left -->
                <div class="flex flex-col w-full md:w-auto py-8 md:py-16 md:relative">
                    <div class="flex flex-col bg-brandGreen rounded-xl p-6 text-white text-sm space-y-4 md:top-14 md:-left-28 md:absolute">
                        <img src="assets/bg/bg_img_contact.svg" alt="Contact Us" class="w-auto"/>
                        <h5 class="font-bold text-left pt-4 capitalize">Contact us with</h5>
                        <p class="flex flex-row space-x-2 font-light items-start text-sm">
                            <span><img src="assets/icons/ic_phone.svg" alt="Phone" class="w-4"/></span>
                            <a href="tel:+02079460018">(020) 7946 0018</a>

                        </p>
                        <p class="flex flex-row space-x-2 font-light items-start text-sm">
                            <span><img src="assets/icons/ic_mail.svg" alt="Mail" class="w-4"/></span>
                            <a href="mailto:holidayservices@support.com">holidayservices@support.com</a>

                        </p>
                        <div class="flex flex-row space-x-4">
                            <!-- Link 1 -->
                            <a href="#">
                                <img src="assets/icons/ic_social_tiktok_footer.svg" alt="Tiktok" class="h-8" />
                            </a>
                            <!-- Link 1 -->
                            <a href="#">
                                <img src="assets/icons/ic_social_instagram_footer.svg" alt="Instagram" class="h-8" />
                            </a>
                            <!-- Link 1 -->
                            <a href="#">
                                <img src="assets/icons/ic_social_facebook_footer.svg" alt="facebook" class="h-8" />
                            </a>

                        </div>
                    </div>
                </div>

                <!-- Right -->
                <div class="flex-initial w-full md:w-5/6 border-2 rounded-xl border-brandGreen">
                    <div class="flex flex-col space-y-4">
                        <div class="flex flex-col py-8 px-6 space-y-4">
                            <div class="md:pl-36 space-y-4 flex flex-col">
                                @if (session()->has('error'))
                                    <div class="alert-danger p-4 rounded-md border border-red-500 bg-red-50 text-red-700 flex items-center gap-3">
                                        ⚠️ {{ session()->get('error') }}
                                    </div>
                                @endif

                                @if(session()->has('success'))
                                    <div class="alert-success p-4 rounded-md border border-green-500 bg-green-50 text-green-700 flex items-center gap-3">
                                        ✅ {{ session()->get('success') }}
                                    </div>
                                @endif
                            </div>
                        </div>
                        <form class="flex flex-col py-8 px-6 space-y-4" action="{{ route('contact.submit') }}" method="POST">
                            @csrf
                            <div class="flex flex-col pb-4">
                                <h3 class="text-black font-bold text-md text-center">Leave Us a Message</h3>
                            </div>
                            <div class="md:pl-36 space-y-4 flex flex-col">
                                <div class="flex flex-col ">
                                    <label for="name" class="w-full font-semibold text-xs">Name</label>
                                    <input type="text" id="name" name="name" placeholder="Enter Name" class="text-sm text-fontBase rounded-sm bg-white border border-borderGray focus:ring-transparent focus:border-brandGreen block w-full text-left p-2"/>
                                    @error('name')
                                        <span class="text-danger">{{ $message }}</span>
                                    @enderror
                                </div>
                                <div class="flex flex-col ">
                                    <label for="email" class="w-full font-semibold text-xs">Email</label>
                                    <input type="email" id="email"  name="email" placeholder="Enter Email" class="text-sm text-fontBase rounded-sm bg-white border border-borderGray focus:ring-transparent focus:border-brandGreen block w-full text-left p-2"/>
                                    @error('email')
                                        <span class="text-danger">{{ $message }}</span>
                                    @enderror
                                </div>
                                <div class="flex flex-col ">
                                    <label for="phone" class="w-full font-semibold text-xs">Phone</label>
                                    <input type="text" id="phone" name="phone" placeholder="Enter Phone Number" class="text-sm text-fontBase rounded-sm bg-white border border-borderGray focus:ring-transparent focus:border-brandGreen block w-full text-left p-2"/>
                                    @error('phone')
                                        <span class="text-danger">{{ $message }}</span>
                                    @enderror
                                </div>
                                <div class="flex flex-col">
                                    <label for="subject" class="w-full font-semibold text-xs">Subject</label>
                                    <select id="subject" name="subject" class="text-sm text-fontBase rounded-sm bg-white border border-borderGray focus:ring-transparent focus:border-brandGreen block w-full text-left p-2">
                                        <option selected>Choose the Subject</option>
                                        <option value="S1">Lorem ipsum dolor sit amet </option>
                                        <option value="S2">Consectetur adipisicing elite .</option>
                                        <option value="S3">Dolor sit amet </option>
                                    </select>
                                    @error('subject')
                                        <span class="text-danger">{{ $message }}</span>
                                    @enderror
                                </div>
                                <div class="flex flex-col">
                                    <label for="message" class="w-full font-semibold text-xs">Message</label>
                                    <textarea id="message" name="message" placeholder="Enter your message" class="text-sm text-fontBase rounded-sm bg-white border border-borderGray focus:ring-transparent focus:border-brandGreen block w-full text-left p-2"></textarea>
                                    @error('message')
                                        <span class="text-danger">{{ $message }}</span>
                                    @enderror
                                </div>
                                <div class="flex flex-col">
                                    <button type="submit" class="text-sm uppercase font-bold bg-brandGreen text-white flex flex-row justify-center items-center w-56 h-12 rounded p-4 mx-auto">Submit</button>
                                </div>
                            </div>
                        </form>

                    </div>
                </div>
            </div>
        </div>

    </section>
@endsection
